@@ -31,6 +31,7 @@ Distributed under the terms of the GNU General Public License v2
 import math
 import signal
 import socket
+import ssl
 import subprocess
 import sys
 import time
@@ -41,6 +42,7 @@ if sys.version_info[0] >= 3:
 	url_parse = urllib.parse.urlparse
 	url_unparse = urllib.parse.urlunparse
 	url_open = urllib.request.urlopen
+	url_request = urllib.request.Request
 	HTTPError = urllib.error.HTTPError
 	import http.client
 	IncompleteRead = http.client.IncompleteRead
@@ -50,6 +52,7 @@ else:
 	url_parse = urlparse.urlparse
 	url_unparse = urlparse.urlunparse
 	url_open = urllib2.urlopen
+	url_request = urllib2.Request
 	HTTPError = urllib2.HTTPError
 	import httplib
 	IncompleteRead = httplib.IncompleteRead
@@ -367,7 +370,9 @@ class Deep(object):
 			try:
 				signal.alarm(int(math.ceil(maxtime)))
 				stime = time.time()
-				f = url_open(test_url)
+				r = url_request(test_url)
+				r.host = url_parts.netloc
+				f = url_open(r)
 
 				md5 = hashlib.md5(f.read()).hexdigest()
 
@@ -387,7 +392,7 @@ class Deep(object):
 			finally:
 				signal.alarm(0)
 
-		except EnvironmentError as e:
+		except (EnvironmentError, ssl.CertificateError) as e:
 			self.output.write(('\ndeeptime(): download from host %s '
 				'failed for ip %s: %s\n') % (url_parts.hostname, ip, e), 2)
 			return (None, True)
@@ -418,7 +423,9 @@ class Deep(object):
 		try:
 			try:
 				signal.alarm(self._connect_timeout)
-				f = url_open(test_url)
+				r = url_request(test_url)
+				r.host = url_parts.netloc
+				f = url_open(r)
 				early_out = True
 			finally:
 				signal.alarm(0)
@@ -430,7 +437,7 @@ class Deep(object):
 			if len(ips) == 1:
 				test_url = url_unparse(url_parts)
 				return self._test_connection(test_url, url_parts, ip, [])
-		except EnvironmentError as e:
+		except (EnvironmentError, ssl.CertificateError) as e:
 			self.output.write('deeptime(): connection to host %s '
 				'failed for ip %s:\n            %s\n'
 				% (url_parts.hostname, ip, e), 2)
